Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrecht Van Lommel <brechtvanlommel@gmail.com>2018-06-22 15:42:03 +0300
committerBrecht Van Lommel <brechtvanlommel@gmail.com>2018-06-25 14:35:41 +0300
commita99dcab148ed209409f3b2479ada12d869ae84b6 (patch)
tree2b7fc55752cbe3538fc05c8f77fd86b18a0d6df7 /source/blender/depsgraph/DEG_depsgraph_physics.h
parent5b3ff9f7d890554ae87e63095f24ac6d31a36d3c (diff)
Depsgraph: cache collision relations, for performance and stability.
Same reasoning as effector relations in earlier commit.
Diffstat (limited to 'source/blender/depsgraph/DEG_depsgraph_physics.h')
-rw-r--r--source/blender/depsgraph/DEG_depsgraph_physics.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/source/blender/depsgraph/DEG_depsgraph_physics.h b/source/blender/depsgraph/DEG_depsgraph_physics.h
index 6bffe0c2358..c90f66838cc 100644
--- a/source/blender/depsgraph/DEG_depsgraph_physics.h
+++ b/source/blender/depsgraph/DEG_depsgraph_physics.h
@@ -34,15 +34,21 @@
struct Colllection;
struct Depsgraph;
+struct ListBase;
#ifdef __cplusplus
extern "C" {
#endif
/* Get effector relations from collection or entire scene during evaluation,
* these are created during depsgraph relations building. */
struct ListBase *DEG_get_effector_relations(const struct Depsgraph *depsgraph,
struct Collection *collection);
+struct ListBase *DEG_get_collision_relations(const struct Depsgraph *depsgraph,
+ struct Collection *collection);
+struct ListBase *DEG_get_smoke_collision_relations(const struct Depsgraph *depsgraph,
+ struct Collection *collection);
#ifdef __cplusplus
} /* extern "C" */
@@ -34,15 +34,21 @@
extern "C" {
#endif
-/* Get effector relations from collection or entire scene during evaluation,
- * these are created during depsgraph relations building. */
+/* Get collision/effector relations from collection or entire scene. These
+ * created during depsgraph relations building and should only be accessed
+ * during evaluation. */
struct ListBase *DEG_get_effector_relations(const struct Depsgraph *depsgraph,
struct Collection *collection);